@@ -12,9 +12,6 @@
 #include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
-#ifdef HAVE_BOOL_H
-#include <bool.h>
-#endif
 #ifdef LIBPTH
 # include <pth.h>
 #elif defined(PTHREADEDMPEG)
@@ -24,7 +21,7 @@
 #ifndef _L__SOUND__
 #define _L__SOUND__
 
-/* Not all OSS implementations define an endian-independant samplesize. 
+/* Not all OSS implementations define an endian-independant samplesize.
  * This code is taken from linux' <sys/soundcard.h, OSS version 0x030802
  */
 #ifndef AFMT_S16_NE
@@ -164,7 +161,7 @@ struct buffer_node {
 };
 #endif
 
-enum soundtype { NONE, RAW, WAV };
+enum soundtype { ST_NONE, ST_RAW, ST_WAV };
 
 typedef struct _waveheader {
   u_int32_t     main_chunk;  // 'RIFF'
@@ -355,7 +352,7 @@ public:
   virtual int  getblocksize(void);
 
   int geterrorcode(void) {return __errorcode;};
-  int audiohandle;  
+  int audiohandle;
   virtual int fix_samplesize(void *buffer, int size);
 protected:
   bool seterrorcode(int errorno) {__errorcode=errorno; return false;};
@@ -710,7 +707,7 @@ public:
 #ifdef NEWTHREAD
   int skip;
   unsigned char *sound_buf;
-  void continueplaying(void); 
+  void continueplaying(void);
   void createplayer(void);
   void abortplayer(void);
   void pauseplaying(void);
@@ -730,7 +727,7 @@ private:
   void makeroom(int size);
 
 public:
-	void real_alarm_handler(int bla); 
+	void real_alarm_handler(int bla);
 
   int getfreebuffers(void);
   /*******************************/
@@ -885,7 +882,7 @@ private:
 
   void layer3hybrid(int ch,int gr,REAL in[SBLIMIT][SSLIMIT],
 		                  REAL out[SSLIMIT][SBLIMIT]);
-  
+
   void huffmandecoder_1(const HUFFMANCODETABLE *h,int *x,int *y);
   void huffmandecoder_2(const HUFFMANCODETABLE *h,int *x,int *y,int *v,int *w);
 
@@ -964,7 +961,7 @@ public:
 
   int geterrorcode(void)        {return __errorcode;};
 	struct song_info getsonginfo() { return info;};
-  virtual bool openfile(const char *filename, const char *device, soundtype write2file=NONE)=0;
+  virtual bool openfile(const char *filename, const char *device, soundtype write2file=ST_NONE)=0;
   virtual void closefile(void)                       =0;
   virtual void setforcetomono(short flag)            =0;
 	virtual void setdownfrequency(int)                 =0;
@@ -982,11 +979,11 @@ public:
 	virtual bool ready()                               =0;
 	virtual int elapsed_time()                         =0;
 	virtual int remaining_time()                       =0;
-  
+
 protected:
   Fileplayer(); //thou shallt not instantiate fileplayer itself.
 
-  bool opendevice(const char *device, soundtype write2file=NONE);
+  bool opendevice(const char *device, soundtype write2file=ST_NONE);
 	void set_driver(audiodriver_t driver);
   bool seterrorcode(int errorno){__errorcode=errorno;return false;};
   Soundplayer *player;
@@ -1012,8 +1009,8 @@ public:
   Wavefileplayer(audiodriver_t driver);
   ~Wavefileplayer();
 
-  bool openfile(const char *filename, const char *device, soundtype write2file=NONE);
-  void closefile(void); 
+  bool openfile(const char *filename, const char *device, soundtype write2file=ST_NONE);
+  void closefile(void);
   void setforcetomono(short flag);
 	void setdownfrequency(int value) { if (value); }
   void set8bitmode() { if(player) player->set8bitmode(); }
@@ -1029,7 +1026,7 @@ public:
 	int elapsed_time();
 	int remaining_time();
 	void skip(int);
-  
+
 private:
   Soundinputstream *loader;
 
@@ -1045,7 +1042,7 @@ public:
   Mpegfileplayer(audiodriver_t driver);
   ~Mpegfileplayer();
 
-  bool openfile(const char *filename, const char *device, soundtype write2file=NONE);
+  bool openfile(const char *filename, const char *device, soundtype write2file=ST_NONE);
   void closefile(void);
   void setforcetomono(short flag);
   void set8bitmode() { if (server) server->set8bitmode(); }
@@ -1093,7 +1090,7 @@ public:
   Oggplayer(audiodriver_t driver);
   ~Oggplayer();
 
-  bool openfile(const char *filename, const char *device, soundtype write2file=NONE);
+  bool openfile(const char *filename, const char *device, soundtype write2file=ST_NONE);
   void closefile(void);
   void setforcetomono(short flag);
   void set8bitmode();
@@ -1140,7 +1137,7 @@ public:
 	SIDfileplayer(audiodriver_t driver);
 	~SIDfileplayer();
 
-	bool openfile(const char *filename, const char *device, soundtype write2file=NONE);
+	bool openfile(const char *filename, const char *device, soundtype write2file=ST_NONE);
 	bool initialize(void *data) { if(data); return true; }
 	void closefile(void);
 	void setforcetomono(short flag);
